@@ -20,11 +20,17 @@ if not os.getenv("READ_THE_DOCS"):
         FileLineQueryRequest,
         FileQueryRequest,
         HeaderFileQueryRequest,
-        LineBasedRectangle,
-        PositionQuery,
         SegYQueryRequest,
     )
-    from cognite.seismic.protos.types_pb2 import CRS, FileStep, GeoJson, Geometry, Wkt
+    from cognite.seismic.protos.types_pb2 import (
+        CRS,
+        FileStep,
+        GeoJson,
+        Geometry,
+        Wkt,
+        LineBasedRectangle,
+        PositionQuery,
+    )
     from google.protobuf.empty_pb2 import Empty
     import google.protobuf.wrappers_pb2 as wrappers
 
@@ -136,12 +142,12 @@ class FileAPI(API):
 
     def get_segy_by_lines(
         self,
+        top_left_inline: int,
+        top_left_xline: int,
+        bottom_right_inline: int,
+        bottom_right_xline: int,
         file_id: Optional[str] = None,
         file_name: Optional[str] = None,
-        top_left_inline: int = None,
-        top_left_xline: int = None,
-        bottom_right_inline: int = None,
-        bottom_right_xline: int = None,
     ):
         """Get a part of a SEGY file with data inside a given range of inlines and xlines
 
